@@ -1,7 +1,7 @@
 context("conversion tests")
 
 
-dat <- Sys.Date()
+dat  <- as.Date("2019-03-07")
 datw <- date2week(dat, 5)
 
 
@@ -22,6 +22,16 @@ test_that("a character can be converted to a date", {
 
 })
 
+test_that("character can be converted to aweek if in YYYYMMDD format", {
+
+  expect_identical(date2week("2019/03/07", 5), datw)
+  expect_identical(date2week("2019:03:07", 5, format = "%Y:%m:%d"), datw)
+  expect_identical(date2week("3/7/2019", 5, format = "%m/%d/%Y"), datw)
+  expect_identical(date2week("7/3/2019", 5, format = "%d/%m/%Y"), datw)
+  expect_error(date2week(c("2019-07-03", "7/3/2019"), 5), "The first incorrect date is 7/3/2019")
+
+})
+
 test_that("aweek can be converted to character", {
 
   expect_failure(expect_output(print(as.character(datw)), "aweek start: Friday"))
@@ -30,18 +40,18 @@ test_that("aweek can be converted to character", {
 
 test_that("aweek can be converted to POSIXlt", {
 
-  p <- as.POSIXlt(datw)
-  expect_identical(as.POSIXlt(dat), p)
+  p <- as.POSIXlt(datw, tz = "UTC")
+  expect_identical(as.POSIXlt(dat, tz = "UTC"), p)
 
 })
 
 
 test_that("aweek can be converted to POSIXlt", {
 
-  p <- as.POSIXlt(datw)
+  p <- as.POSIXlt(datw, tz = "UTC")
   expect_identical(as.POSIXlt(dat), p)
 
-  p2 <- as.POSIXlt(datw, floor_day = TRUE)
+  p2 <- as.POSIXlt(datw, tz = "UTC", floor_day = TRUE)
   expect_failure(expect_identical(p, p2))
 
   expect_true(p2 <= p)
